Installation guide
==================
A working python 3 installation is required (versions >=3.7 are possible).

It is highly recommended to use this module in combination with
`Ipython <http://ipython.org/>`_ and `jupyter <http://jupyter.org/>`_.
They come shipped by default with the
`anaconda3 installer <https://www.continuum.io/downloads/>`_.

Unix
++++


For the packaged versions, the following commands have to be executed in the
terminal::

  conda install -c mcocdawc chemcoord

or::

  pip install chemcoord


For the up to date development version (experimental)::

  git clone https://github.com/mcocdawc/chemcoord.git
  cd chemcoord
  pip install .

Windows
+++++++

Neither installation nor running the module are tested on windows.
To the best of my knowledge it should work there as well.
Just use the same steps as for UNIX.
